@@ -3,10 +3,23 @@ import csv
 
 
 def create_download_link(dataframe,
-                         filename,
-                         file_type='csv',
-                         index=False,
-                         header=True):
+                         filename: str,
+                         file_type: str = 'csv',
+                         index: bool = False,
+                         header: bool = True):
+    """
+    Generate a download link for a pandas dataframe.
+
+    Args:
+        dataframe: Pandas DataFrame
+        filename: Name of exported file
+        file_type: Either 'csv' or 'tsv'
+        index: Whether to include index of dataframe or not
+        header: Whether to include header of dataframe or not
+
+    Returns:
+        Markdown to place in st.markdown(...)
+    """
     if file_type == 'csv':
         dataframe_csv = dataframe.to_csv(index=index)
     elif file_type == 'tsv':
